.. ref_videofx:

***********************
moviepy.video.fx (vfx)
***********************
The module ``moviepy.video.fx`` regroups functions meant to be used with ``videoclip.fx``. When you type ::
    
    from moviepy.editor import *

the module ``video.fx`` is loaded as ``vfx`` and you can use ``vfx.colorx``, ``vfx.resize``, etc.


.. currentmodule:: moviepy.video.fx

.. autosummary::
    :toctree: videofx
    :nosignatures:
    
    blackwhite
    blink
    colorx
    crop
    fadein
    fadeout
    freeze_at_end
    freeze_at_start
    gamma_corr
    headblur
    loop
    lum_contrast
    make_loopable
    margin
    mirror_x
    mirror_y
    painting
    resize
    rotation
    scroll
    speedx
    time_mirror
    time_symetrize


   
